@@ -7,3 +7,12 @@ test_that("html: only single message body", {
   expect_error(envelope() %>% html("foo"), NA)
   expect_error(envelope() %>% html(c("foo", "bar")))
 })
+
+test_that("html: HTML from file", {
+  expect_true(
+    grepl(
+      HTMLCONTENT,
+      envelope() %>% html(HTMLPATH) %>% as.character()
+    )
+  )
+})
